AnythingSlider Video Demo

- Your browser does not support the video tag. But you could include an iframe/embeded video here.

## AnythingSlider Video Extension Compatibility

Video Type | Function | Browser
--- | --- | ---
FF | C | S | O | IE9 | IE8 | IE7
Vimeo iframe | Setup |  |  |  |  |  |  |
Continue |  |  |  |  |  |  |
Pause |  |  |  |  |  |  |
Pause Slideshow |  |  |  |  |  |  |
Vimeo embed | Setup |  |  |  |  |  |  |
Continue |  |  |  |  |  |  |
Pause |  |  |  |  |  |  |
Pause Slideshow |  |  |  |  |  |  |
YouTube iframe | Setup |  |  |  |  |  |  |
Continue * |  |  |  |  |  |  |
Pause |  |  |  |  |  |  |
Pause Slideshow |  |  |  |  |  |  |
YouTube embed | Setup |  |  |  |  |  |  |
Continue |  |  |  |  |  |  |
Pause |  |  |  |  |  |  |
Pause Slideshow |  |  |  |  |  |  |
HTML5 Video | Setup |  |  |  |  |  |  |
Continue |  |  |  |  |  |  |
Pause |  |  |  |  |  |  |
Pause Slideshow |  |  |  |  |  |  |

### Legend

- (*) YouTube iframe
  - The video autoplays (continues) the second time the video comes into view, because it gets paused even though it hasn't started; oddly this isn't a problem in Firefox. Still working on a fix.
  - Watching a related video breaks the ability if the slider to continue playing and pause the slideshow while playing these videos. This is because the iframe does not update the video URL and there is no way, that I know of, of determining which iframe is reporting a status change.
- (FF) Firefox 3+ - No problems noted.
- (C) Chrome - Ignore "Unsafe JavaScript attempt to access frame with URL" error.
- (S) Safari 4+
  - HTML5 video shows up as a black box when it should be hidden by overflow (at least in Windows).
  - In Safari for Windows, including an HTML5 along with other videos appears to offset every video down and right (about 100px) for an unknown reason. For now, this issue can be solved by keeping HTML5 videos separate from other videos.
- (O) Opera 9+ - YouTube iframe does not update player status when the script controls it (reported). So this breaks this extension's ability to resume a video and pause the slideshow.
- (IE9) Internet Explorer 9 - See "*" Note above.
- (IE8) Internet Explorer 8 - no support for HTML5.
- (IE7) Internet Explorer 7 - no support for HTML5 and no support for iframe communication.